# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: communities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import groups_pb2 as groups__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='communities.proto',
  package='org.couchers.api.communities',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x63ommunities.proto\x12\x1corg.couchers.api.communities\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0cgroups.proto\x1a\x0bpages.proto\"\xdd\x02\n\tCommunity\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12/\n\tmain_page\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x0e\n\x06member\x18\x08 \x01(\x08\x12\r\n\x05\x61\x64min\x18\t \x01(\x08\x12\x14\n\x0cmember_count\x18\n \x01(\r\x12\x13\n\x0b\x61\x64min_count\x18\x0b \x01(\r\x12\x19\n\x11nearby_user_count\x18\x0c \x01(\r\x12\x14\n\x0c\x63\x61n_moderate\x18\r \x01(\x08\"\'\n\x0fGetCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\"Q\n\x12ListCommunitiesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"k\n\x12ListCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x16ListUserCommunitiesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"o\n\x16ListUserCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListGroupsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListGroupsRes\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.groups.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListAdminsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"@\n\rListAdminsRes\x12\x16\n\x0e\x61\x64min_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"M\n\x0eListMembersReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"B\n\x0eListMembersRes\x12\x17\n\x0fmember_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x12ListNearbyUsersReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"F\n\x12ListNearbyUsersRes\x12\x17\n\x0fnearby_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListPlacesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListGuidesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Z\n\rListEventsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x04 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x12ListDiscussionsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"l\n\x12ListDiscussionsRes\x12=\n\x0b\x64iscussions\x18\x01 \x03(\x0b\x32(.org.couchers.api.discussions.Discussion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"(\n\x10JoinCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\")\n\x11LeaveCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x32\xa5\x0b\n\x0b\x43ommunities\x12h\n\x0cGetCommunity\x12-.org.couchers.api.communities.GetCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12w\n\x0fListCommunities\x12\x30.org.couchers.api.communities.ListCommunitiesReq\x1a\x30.org.couchers.api.communities.ListCommunitiesRes\"\x00\x12h\n\nListGroups\x12+.org.couchers.api.communities.ListGroupsReq\x1a+.org.couchers.api.communities.ListGroupsRes\"\x00\x12h\n\nListAdmins\x12+.org.couchers.api.communities.ListAdminsReq\x1a+.org.couchers.api.communities.ListAdminsRes\"\x00\x12k\n\x0bListMembers\x12,.org.couchers.api.communities.ListMembersReq\x1a,.org.couchers.api.communities.ListMembersRes\"\x00\x12w\n\x0fListNearbyUsers\x12\x30.org.couchers.api.communities.ListNearbyUsersReq\x1a\x30.org.couchers.api.communities.ListNearbyUsersRes\"\x00\x12h\n\nListPlaces\x12+.org.couchers.api.communities.ListPlacesReq\x1a+.org.couchers.api.communities.ListPlacesRes\"\x00\x12h\n\nListGuides\x12+.org.couchers.api.communities.ListGuidesReq\x1a+.org.couchers.api.communities.ListGuidesRes\"\x00\x12h\n\nListEvents\x12+.org.couchers.api.communities.ListEventsReq\x1a+.org.couchers.api.communities.ListEventsRes\"\x00\x12w\n\x0fListDiscussions\x12\x30.org.couchers.api.communities.ListDiscussionsReq\x1a\x30.org.couchers.api.communities.ListDiscussionsRes\"\x00\x12Y\n\rJoinCommunity\x12..org.couchers.api.communities.JoinCommunityReq\x1a\x16.google.protobuf.Empty\"\x00\x12[\n\x0eLeaveCommunity\x12/.org.couchers.api.communities.LeaveCommunityReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x83\x01\n\x13ListUserCommunities\x12\x34.org.couchers.api.communities.ListUserCommunitiesReq\x1a\x34.org.couchers.api.communities.ListUserCommunitiesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,discussions__pb2.DESCRIPTOR,events__pb2.DESCRIPTOR,groups__pb2.DESCRIPTOR,pages__pb2.DESCRIPTOR,])




_COMMUNITY = _descriptor.Descriptor(
  name='Community',
  full_name='org.couchers.api.communities.Community',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.Community.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.communities.Community.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.communities.Community.slug', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.api.communities.Community.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.api.communities.Community.created', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parents', full_name='org.couchers.api.communities.Community.parents', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_page', full_name='org.couchers.api.communities.Community.main_page', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='org.couchers.api.communities.Community.member', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='org.couchers.api.communities.Community.admin', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='org.couchers.api.communities.Community.member_count', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_count', full_name='org.couchers.api.communities.Community.admin_count', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearby_user_count', full_name='org.couchers.api.communities.Community.nearby_user_count', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_moderate', full_name='org.couchers.api.communities.Community.can_moderate', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=542,
)


_GETCOMMUNITYREQ = _descriptor.Descriptor(
  name='GetCommunityReq',
  full_name='org.couchers.api.communities.GetCommunityReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.GetCommunityReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=583,
)


_LISTCOMMUNITIESREQ = _descriptor.Descriptor(
  name='ListCommunitiesReq',
  full_name='org.couchers.api.communities.ListCommunitiesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListCommunitiesReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListCommunitiesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListCommunitiesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=666,
)


_LISTCOMMUNITIESRES = _descriptor.Descriptor(
  name='ListCommunitiesRes',
  full_name='org.couchers.api.communities.ListCommunitiesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communities', full_name='org.couchers.api.communities.ListCommunitiesRes.communities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListCommunitiesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=775,
)


_LISTUSERCOMMUNITIESREQ = _descriptor.Descriptor(
  name='ListUserCommunitiesReq',
  full_name='org.couchers.api.communities.ListUserCommunitiesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.communities.ListUserCommunitiesReq.user_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListUserCommunitiesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListUserCommunitiesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=857,
)


_LISTUSERCOMMUNITIESRES = _descriptor.Descriptor(
  name='ListUserCommunitiesRes',
  full_name='org.couchers.api.communities.ListUserCommunitiesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='communities', full_name='org.couchers.api.communities.ListUserCommunitiesRes.communities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListUserCommunitiesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=970,
)


_LISTGROUPSREQ = _descriptor.Descriptor(
  name='ListGroupsReq',
  full_name='org.couchers.api.communities.ListGroupsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListGroupsReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListGroupsReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListGroupsReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1048,
)


_LISTGROUPSRES = _descriptor.Descriptor(
  name='ListGroupsRes',
  full_name='org.couchers.api.communities.ListGroupsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='org.couchers.api.communities.ListGroupsRes.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListGroupsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1050,
  serialized_end=1138,
)


_LISTADMINSREQ = _descriptor.Descriptor(
  name='ListAdminsReq',
  full_name='org.couchers.api.communities.ListAdminsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListAdminsReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListAdminsReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListAdminsReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1140,
  serialized_end=1216,
)


_LISTADMINSRES = _descriptor.Descriptor(
  name='ListAdminsRes',
  full_name='org.couchers.api.communities.ListAdminsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='admin_user_ids', full_name='org.couchers.api.communities.ListAdminsRes.admin_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListAdminsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1282,
)


_LISTMEMBERSREQ = _descriptor.Descriptor(
  name='ListMembersReq',
  full_name='org.couchers.api.communities.ListMembersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListMembersReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListMembersReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListMembersReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1361,
)


_LISTMEMBERSRES = _descriptor.Descriptor(
  name='ListMembersRes',
  full_name='org.couchers.api.communities.ListMembersRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_user_ids', full_name='org.couchers.api.communities.ListMembersRes.member_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListMembersRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1363,
  serialized_end=1429,
)


_LISTNEARBYUSERSREQ = _descriptor.Descriptor(
  name='ListNearbyUsersReq',
  full_name='org.couchers.api.communities.ListNearbyUsersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListNearbyUsersReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListNearbyUsersReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListNearbyUsersReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1431,
  serialized_end=1512,
)


_LISTNEARBYUSERSRES = _descriptor.Descriptor(
  name='ListNearbyUsersRes',
  full_name='org.couchers.api.communities.ListNearbyUsersRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nearby_user_ids', full_name='org.couchers.api.communities.ListNearbyUsersRes.nearby_user_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListNearbyUsersRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1584,
)


_LISTPLACESREQ = _descriptor.Descriptor(
  name='ListPlacesReq',
  full_name='org.couchers.api.communities.ListPlacesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListPlacesReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListPlacesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListPlacesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1662,
)


_LISTPLACESRES = _descriptor.Descriptor(
  name='ListPlacesRes',
  full_name='org.couchers.api.communities.ListPlacesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='places', full_name='org.couchers.api.communities.ListPlacesRes.places', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListPlacesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1750,
)


_LISTGUIDESREQ = _descriptor.Descriptor(
  name='ListGuidesReq',
  full_name='org.couchers.api.communities.ListGuidesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListGuidesReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListGuidesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListGuidesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1828,
)


_LISTGUIDESRES = _descriptor.Descriptor(
  name='ListGuidesRes',
  full_name='org.couchers.api.communities.ListGuidesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='guides', full_name='org.couchers.api.communities.ListGuidesRes.guides', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListGuidesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1830,
  serialized_end=1916,
)


_LISTEVENTSREQ = _descriptor.Descriptor(
  name='ListEventsReq',
  full_name='org.couchers.api.communities.ListEventsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListEventsReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='past', full_name='org.couchers.api.communities.ListEventsReq.past', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListEventsReq.page_size', index=2,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListEventsReq.page_token', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=2008,
)


_LISTEVENTSRES = _descriptor.Descriptor(
  name='ListEventsRes',
  full_name='org.couchers.api.communities.ListEventsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='org.couchers.api.communities.ListEventsRes.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListEventsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2010,
  serialized_end=2098,
)


_LISTDISCUSSIONSREQ = _descriptor.Descriptor(
  name='ListDiscussionsReq',
  full_name='org.couchers.api.communities.ListDiscussionsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.ListDiscussionsReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.communities.ListDiscussionsReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.communities.ListDiscussionsReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2181,
)


_LISTDISCUSSIONSRES = _descriptor.Descriptor(
  name='ListDiscussionsRes',
  full_name='org.couchers.api.communities.ListDiscussionsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discussions', full_name='org.couchers.api.communities.ListDiscussionsRes.discussions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.communities.ListDiscussionsRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2183,
  serialized_end=2291,
)


_JOINCOMMUNITYREQ = _descriptor.Descriptor(
  name='JoinCommunityReq',
  full_name='org.couchers.api.communities.JoinCommunityReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.JoinCommunityReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2293,
  serialized_end=2333,
)


_LEAVECOMMUNITYREQ = _descriptor.Descriptor(
  name='LeaveCommunityReq',
  full_name='org.couchers.api.communities.LeaveCommunityReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_id', full_name='org.couchers.api.communities.LeaveCommunityReq.community_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2335,
  serialized_end=2376,
)

_COMMUNITY.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMUNITY.fields_by_name['parents'].message_type = groups__pb2._PARENT
_COMMUNITY.fields_by_name['main_page'].message_type = pages__pb2._PAGE
_LISTCOMMUNITIESRES.fields_by_name['communities'].message_type = _COMMUNITY
_LISTUSERCOMMUNITIESRES.fields_by_name['communities'].message_type = _COMMUNITY
_LISTGROUPSRES.fields_by_name['groups'].message_type = groups__pb2._GROUP
_LISTPLACESRES.fields_by_name['places'].message_type = pages__pb2._PAGE
_LISTGUIDESRES.fields_by_name['guides'].message_type = pages__pb2._PAGE
_LISTEVENTSRES.fields_by_name['events'].message_type = events__pb2._EVENT
_LISTDISCUSSIONSRES.fields_by_name['discussions'].message_type = discussions__pb2._DISCUSSION
DESCRIPTOR.message_types_by_name['Community'] = _COMMUNITY
DESCRIPTOR.message_types_by_name['GetCommunityReq'] = _GETCOMMUNITYREQ
DESCRIPTOR.message_types_by_name['ListCommunitiesReq'] = _LISTCOMMUNITIESREQ
DESCRIPTOR.message_types_by_name['ListCommunitiesRes'] = _LISTCOMMUNITIESRES
DESCRIPTOR.message_types_by_name['ListUserCommunitiesReq'] = _LISTUSERCOMMUNITIESREQ
DESCRIPTOR.message_types_by_name['ListUserCommunitiesRes'] = _LISTUSERCOMMUNITIESRES
DESCRIPTOR.message_types_by_name['ListGroupsReq'] = _LISTGROUPSREQ
DESCRIPTOR.message_types_by_name['ListGroupsRes'] = _LISTGROUPSRES
DESCRIPTOR.message_types_by_name['ListAdminsReq'] = _LISTADMINSREQ
DESCRIPTOR.message_types_by_name['ListAdminsRes'] = _LISTADMINSRES
DESCRIPTOR.message_types_by_name['ListMembersReq'] = _LISTMEMBERSREQ
DESCRIPTOR.message_types_by_name['ListMembersRes'] = _LISTMEMBERSRES
DESCRIPTOR.message_types_by_name['ListNearbyUsersReq'] = _LISTNEARBYUSERSREQ
DESCRIPTOR.message_types_by_name['ListNearbyUsersRes'] = _LISTNEARBYUSERSRES
DESCRIPTOR.message_types_by_name['ListPlacesReq'] = _LISTPLACESREQ
DESCRIPTOR.message_types_by_name['ListPlacesRes'] = _LISTPLACESRES
DESCRIPTOR.message_types_by_name['ListGuidesReq'] = _LISTGUIDESREQ
DESCRIPTOR.message_types_by_name['ListGuidesRes'] = _LISTGUIDESRES
DESCRIPTOR.message_types_by_name['ListEventsReq'] = _LISTEVENTSREQ
DESCRIPTOR.message_types_by_name['ListEventsRes'] = _LISTEVENTSRES
DESCRIPTOR.message_types_by_name['ListDiscussionsReq'] = _LISTDISCUSSIONSREQ
DESCRIPTOR.message_types_by_name['ListDiscussionsRes'] = _LISTDISCUSSIONSRES
DESCRIPTOR.message_types_by_name['JoinCommunityReq'] = _JOINCOMMUNITYREQ
DESCRIPTOR.message_types_by_name['LeaveCommunityReq'] = _LEAVECOMMUNITYREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Community = _reflection.GeneratedProtocolMessageType('Community', (_message.Message,), {
  'DESCRIPTOR' : _COMMUNITY,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.Community)
  })
_sym_db.RegisterMessage(Community)

GetCommunityReq = _reflection.GeneratedProtocolMessageType('GetCommunityReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMUNITYREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.GetCommunityReq)
  })
_sym_db.RegisterMessage(GetCommunityReq)

ListCommunitiesReq = _reflection.GeneratedProtocolMessageType('ListCommunitiesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMUNITIESREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListCommunitiesReq)
  })
_sym_db.RegisterMessage(ListCommunitiesReq)

ListCommunitiesRes = _reflection.GeneratedProtocolMessageType('ListCommunitiesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMUNITIESRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListCommunitiesRes)
  })
_sym_db.RegisterMessage(ListCommunitiesRes)

ListUserCommunitiesReq = _reflection.GeneratedProtocolMessageType('ListUserCommunitiesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERCOMMUNITIESREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListUserCommunitiesReq)
  })
_sym_db.RegisterMessage(ListUserCommunitiesReq)

ListUserCommunitiesRes = _reflection.GeneratedProtocolMessageType('ListUserCommunitiesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERCOMMUNITIESRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListUserCommunitiesRes)
  })
_sym_db.RegisterMessage(ListUserCommunitiesRes)

ListGroupsReq = _reflection.GeneratedProtocolMessageType('ListGroupsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPSREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListGroupsReq)
  })
_sym_db.RegisterMessage(ListGroupsReq)

ListGroupsRes = _reflection.GeneratedProtocolMessageType('ListGroupsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPSRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListGroupsRes)
  })
_sym_db.RegisterMessage(ListGroupsRes)

ListAdminsReq = _reflection.GeneratedProtocolMessageType('ListAdminsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTADMINSREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListAdminsReq)
  })
_sym_db.RegisterMessage(ListAdminsReq)

ListAdminsRes = _reflection.GeneratedProtocolMessageType('ListAdminsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTADMINSRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListAdminsRes)
  })
_sym_db.RegisterMessage(ListAdminsRes)

ListMembersReq = _reflection.GeneratedProtocolMessageType('ListMembersReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListMembersReq)
  })
_sym_db.RegisterMessage(ListMembersReq)

ListMembersRes = _reflection.GeneratedProtocolMessageType('ListMembersRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListMembersRes)
  })
_sym_db.RegisterMessage(ListMembersRes)

ListNearbyUsersReq = _reflection.GeneratedProtocolMessageType('ListNearbyUsersReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTNEARBYUSERSREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListNearbyUsersReq)
  })
_sym_db.RegisterMessage(ListNearbyUsersReq)

ListNearbyUsersRes = _reflection.GeneratedProtocolMessageType('ListNearbyUsersRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTNEARBYUSERSRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListNearbyUsersRes)
  })
_sym_db.RegisterMessage(ListNearbyUsersRes)

ListPlacesReq = _reflection.GeneratedProtocolMessageType('ListPlacesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACESREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListPlacesReq)
  })
_sym_db.RegisterMessage(ListPlacesReq)

ListPlacesRes = _reflection.GeneratedProtocolMessageType('ListPlacesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACESRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListPlacesRes)
  })
_sym_db.RegisterMessage(ListPlacesRes)

ListGuidesReq = _reflection.GeneratedProtocolMessageType('ListGuidesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTGUIDESREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListGuidesReq)
  })
_sym_db.RegisterMessage(ListGuidesReq)

ListGuidesRes = _reflection.GeneratedProtocolMessageType('ListGuidesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTGUIDESRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListGuidesRes)
  })
_sym_db.RegisterMessage(ListGuidesRes)

ListEventsReq = _reflection.GeneratedProtocolMessageType('ListEventsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListEventsReq)
  })
_sym_db.RegisterMessage(ListEventsReq)

ListEventsRes = _reflection.GeneratedProtocolMessageType('ListEventsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListEventsRes)
  })
_sym_db.RegisterMessage(ListEventsRes)

ListDiscussionsReq = _reflection.GeneratedProtocolMessageType('ListDiscussionsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISCUSSIONSREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListDiscussionsReq)
  })
_sym_db.RegisterMessage(ListDiscussionsReq)

ListDiscussionsRes = _reflection.GeneratedProtocolMessageType('ListDiscussionsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISCUSSIONSRES,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.ListDiscussionsRes)
  })
_sym_db.RegisterMessage(ListDiscussionsRes)

JoinCommunityReq = _reflection.GeneratedProtocolMessageType('JoinCommunityReq', (_message.Message,), {
  'DESCRIPTOR' : _JOINCOMMUNITYREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.JoinCommunityReq)
  })
_sym_db.RegisterMessage(JoinCommunityReq)

LeaveCommunityReq = _reflection.GeneratedProtocolMessageType('LeaveCommunityReq', (_message.Message,), {
  'DESCRIPTOR' : _LEAVECOMMUNITYREQ,
  '__module__' : 'communities_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.communities.LeaveCommunityReq)
  })
_sym_db.RegisterMessage(LeaveCommunityReq)



_COMMUNITIES = _descriptor.ServiceDescriptor(
  name='Communities',
  full_name='org.couchers.api.communities.Communities',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=2379,
  serialized_end=3824,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCommunity',
    full_name='org.couchers.api.communities.Communities.GetCommunity',
    index=0,
    containing_service=None,
    input_type=_GETCOMMUNITYREQ,
    output_type=_COMMUNITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCommunities',
    full_name='org.couchers.api.communities.Communities.ListCommunities',
    index=1,
    containing_service=None,
    input_type=_LISTCOMMUNITIESREQ,
    output_type=_LISTCOMMUNITIESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListGroups',
    full_name='org.couchers.api.communities.Communities.ListGroups',
    index=2,
    containing_service=None,
    input_type=_LISTGROUPSREQ,
    output_type=_LISTGROUPSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAdmins',
    full_name='org.couchers.api.communities.Communities.ListAdmins',
    index=3,
    containing_service=None,
    input_type=_LISTADMINSREQ,
    output_type=_LISTADMINSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='org.couchers.api.communities.Communities.ListMembers',
    index=4,
    containing_service=None,
    input_type=_LISTMEMBERSREQ,
    output_type=_LISTMEMBERSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNearbyUsers',
    full_name='org.couchers.api.communities.Communities.ListNearbyUsers',
    index=5,
    containing_service=None,
    input_type=_LISTNEARBYUSERSREQ,
    output_type=_LISTNEARBYUSERSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPlaces',
    full_name='org.couchers.api.communities.Communities.ListPlaces',
    index=6,
    containing_service=None,
    input_type=_LISTPLACESREQ,
    output_type=_LISTPLACESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListGuides',
    full_name='org.couchers.api.communities.Communities.ListGuides',
    index=7,
    containing_service=None,
    input_type=_LISTGUIDESREQ,
    output_type=_LISTGUIDESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEvents',
    full_name='org.couchers.api.communities.Communities.ListEvents',
    index=8,
    containing_service=None,
    input_type=_LISTEVENTSREQ,
    output_type=_LISTEVENTSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDiscussions',
    full_name='org.couchers.api.communities.Communities.ListDiscussions',
    index=9,
    containing_service=None,
    input_type=_LISTDISCUSSIONSREQ,
    output_type=_LISTDISCUSSIONSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinCommunity',
    full_name='org.couchers.api.communities.Communities.JoinCommunity',
    index=10,
    containing_service=None,
    input_type=_JOINCOMMUNITYREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveCommunity',
    full_name='org.couchers.api.communities.Communities.LeaveCommunity',
    index=11,
    containing_service=None,
    input_type=_LEAVECOMMUNITYREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserCommunities',
    full_name='org.couchers.api.communities.Communities.ListUserCommunities',
    index=12,
    containing_service=None,
    input_type=_LISTUSERCOMMUNITIESREQ,
    output_type=_LISTUSERCOMMUNITIESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMUNITIES)

DESCRIPTOR.services_by_name['Communities'] = _COMMUNITIES

# @@protoc_insertion_point(module_scope)
