# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pages.proto',
  package='org.couchers.api.pages',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bpages.proto\x12\x16org.couchers.api.pages\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"&\n\nCoordinate\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\"\xb0\x04\n\x04Page\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .org.couchers.api.pages.PageType\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_edited\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13last_editor_user_id\x18\x06 \x01(\x03\x12\x17\n\x0f\x63reator_user_id\x18\x07 \x01(\x03\x12\x17\n\rowner_user_id\x18\x08 \x01(\x03H\x00\x12\x1c\n\x12owner_community_id\x18\x11 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\t \x01(\x03H\x00\x12\x30\n\x06thread\x18\x14 \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\r\n\x05title\x18\x0b \x01(\t\x12\x0f\n\x07\x63ontent\x18\x0c \x01(\t\x12\x11\n\tphoto_url\x18\x13 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\r \x01(\t\x12\x34\n\x08location\x18\x0e \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\x12\x17\n\x0f\x65\x64itor_user_ids\x18\x0f \x03(\x03\x12\x10\n\x08\x63\x61n_edit\x18\x10 \x01(\x08\x12\x14\n\x0c\x63\x61n_moderate\x18\x12 \x01(\x08\x42\x07\n\x05owner\"\x8a\x01\n\x0e\x43reatePlaceReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x05 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x34\n\x08location\x18\x04 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"\xa7\x01\n\x0e\x43reateGuideReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x06 \x01(\t\x12\x1b\n\x13parent_community_id\x18\x03 \x01(\x03\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\x12\x34\n\x08location\x18\x05 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"\x1d\n\nGetPageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\"\x92\x02\n\rUpdatePageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12+\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tphoto_key\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x08location\x18\x05 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"o\n\x0fTransferPageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12 \n\x16new_owner_community_id\x18\x03 \x01(\x03H\x00\x12\x1c\n\x12new_owner_group_id\x18\x02 \x01(\x03H\x00\x42\x0b\n\tnew_owner\"K\n\x11ListUserPlacesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Z\n\x11ListUserPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"K\n\x11ListUserGuidesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Z\n\x11ListUserGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*M\n\x08PageType\x12\x13\n\x0fPAGE_TYPE_PLACE\x10\x00\x12\x13\n\x0fPAGE_TYPE_GUIDE\x10\x01\x12\x17\n\x13PAGE_TYPE_MAIN_PAGE\x10\x02\x32\x8c\x05\n\x05Pages\x12U\n\x0b\x43reatePlace\x12&.org.couchers.api.pages.CreatePlaceReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12U\n\x0b\x43reateGuide\x12&.org.couchers.api.pages.CreateGuideReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12M\n\x07GetPage\x12\".org.couchers.api.pages.GetPageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12S\n\nUpdatePage\x12%.org.couchers.api.pages.UpdatePageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12W\n\x0cTransferPage\x12\'.org.couchers.api.pages.TransferPageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12h\n\x0eListUserPlaces\x12).org.couchers.api.pages.ListUserPlacesReq\x1a).org.couchers.api.pages.ListUserPlacesRes\"\x00\x12h\n\x0eListUserGuides\x12).org.couchers.api.pages.ListUserGuidesReq\x1a).org.couchers.api.pages.ListUserGuidesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,threads__pb2.DESCRIPTOR,])

_PAGETYPE = _descriptor.EnumDescriptor(
  name='PageType',
  full_name='org.couchers.api.pages.PageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PAGE_TYPE_PLACE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAGE_TYPE_GUIDE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAGE_TYPE_MAIN_PAGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1811,
  serialized_end=1888,
)
_sym_db.RegisterEnumDescriptor(_PAGETYPE)

PageType = enum_type_wrapper.EnumTypeWrapper(_PAGETYPE)
PAGE_TYPE_PLACE = 0
PAGE_TYPE_GUIDE = 1
PAGE_TYPE_MAIN_PAGE = 2



_COORDINATE = _descriptor.Descriptor(
  name='Coordinate',
  full_name='org.couchers.api.pages.Coordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.api.pages.Coordinate.lat', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.api.pages.Coordinate.lng', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=176,
)


_PAGE = _descriptor.Descriptor(
  name='Page',
  full_name='org.couchers.api.pages.Page',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_id', full_name='org.couchers.api.pages.Page.page_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='org.couchers.api.pages.Page.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.pages.Page.slug', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.api.pages.Page.created', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_edited', full_name='org.couchers.api.pages.Page.last_edited', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_editor_user_id', full_name='org.couchers.api.pages.Page.last_editor_user_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_user_id', full_name='org.couchers.api.pages.Page.creator_user_id', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_user_id', full_name='org.couchers.api.pages.Page.owner_user_id', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_community_id', full_name='org.couchers.api.pages.Page.owner_community_id', index=8,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_group_id', full_name='org.couchers.api.pages.Page.owner_group_id', index=9,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thread', full_name='org.couchers.api.pages.Page.thread', index=10,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.pages.Page.title', index=11,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.pages.Page.content', index=12,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_url', full_name='org.couchers.api.pages.Page.photo_url', index=13,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='org.couchers.api.pages.Page.address', index=14,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='org.couchers.api.pages.Page.location', index=15,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='editor_user_ids', full_name='org.couchers.api.pages.Page.editor_user_ids', index=16,
      number=15, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_edit', full_name='org.couchers.api.pages.Page.can_edit', index=17,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_moderate', full_name='org.couchers.api.pages.Page.can_moderate', index=18,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='owner', full_name='org.couchers.api.pages.Page.owner',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=179,
  serialized_end=739,
)


_CREATEPLACEREQ = _descriptor.Descriptor(
  name='CreatePlaceReq',
  full_name='org.couchers.api.pages.CreatePlaceReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.pages.CreatePlaceReq.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.pages.CreatePlaceReq.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_key', full_name='org.couchers.api.pages.CreatePlaceReq.photo_key', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='org.couchers.api.pages.CreatePlaceReq.address', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='org.couchers.api.pages.CreatePlaceReq.location', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=742,
  serialized_end=880,
)


_CREATEGUIDEREQ = _descriptor.Descriptor(
  name='CreateGuideReq',
  full_name='org.couchers.api.pages.CreateGuideReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.pages.CreateGuideReq.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.pages.CreateGuideReq.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_key', full_name='org.couchers.api.pages.CreateGuideReq.photo_key', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_community_id', full_name='org.couchers.api.pages.CreateGuideReq.parent_community_id', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='org.couchers.api.pages.CreateGuideReq.address', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='org.couchers.api.pages.CreateGuideReq.location', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=883,
  serialized_end=1050,
)


_GETPAGEREQ = _descriptor.Descriptor(
  name='GetPageReq',
  full_name='org.couchers.api.pages.GetPageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_id', full_name='org.couchers.api.pages.GetPageReq.page_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1081,
)


_UPDATEPAGEREQ = _descriptor.Descriptor(
  name='UpdatePageReq',
  full_name='org.couchers.api.pages.UpdatePageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_id', full_name='org.couchers.api.pages.UpdatePageReq.page_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='org.couchers.api.pages.UpdatePageReq.title', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.pages.UpdatePageReq.content', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo_key', full_name='org.couchers.api.pages.UpdatePageReq.photo_key', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='org.couchers.api.pages.UpdatePageReq.address', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='org.couchers.api.pages.UpdatePageReq.location', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1358,
)


_TRANSFERPAGEREQ = _descriptor.Descriptor(
  name='TransferPageReq',
  full_name='org.couchers.api.pages.TransferPageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_id', full_name='org.couchers.api.pages.TransferPageReq.page_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_owner_community_id', full_name='org.couchers.api.pages.TransferPageReq.new_owner_community_id', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_owner_group_id', full_name='org.couchers.api.pages.TransferPageReq.new_owner_group_id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='new_owner', full_name='org.couchers.api.pages.TransferPageReq.new_owner',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1360,
  serialized_end=1471,
)


_LISTUSERPLACESREQ = _descriptor.Descriptor(
  name='ListUserPlacesReq',
  full_name='org.couchers.api.pages.ListUserPlacesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.pages.ListUserPlacesReq.user_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.pages.ListUserPlacesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.pages.ListUserPlacesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1548,
)


_LISTUSERPLACESRES = _descriptor.Descriptor(
  name='ListUserPlacesRes',
  full_name='org.couchers.api.pages.ListUserPlacesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='places', full_name='org.couchers.api.pages.ListUserPlacesRes.places', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.pages.ListUserPlacesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1550,
  serialized_end=1640,
)


_LISTUSERGUIDESREQ = _descriptor.Descriptor(
  name='ListUserGuidesReq',
  full_name='org.couchers.api.pages.ListUserGuidesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.pages.ListUserGuidesReq.user_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.pages.ListUserGuidesReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.pages.ListUserGuidesReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1642,
  serialized_end=1717,
)


_LISTUSERGUIDESRES = _descriptor.Descriptor(
  name='ListUserGuidesRes',
  full_name='org.couchers.api.pages.ListUserGuidesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='guides', full_name='org.couchers.api.pages.ListUserGuidesRes.guides', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.pages.ListUserGuidesRes.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1809,
)

_PAGE.fields_by_name['type'].enum_type = _PAGETYPE
_PAGE.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PAGE.fields_by_name['last_edited'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PAGE.fields_by_name['thread'].message_type = threads__pb2._THREAD
_PAGE.fields_by_name['location'].message_type = _COORDINATE
_PAGE.oneofs_by_name['owner'].fields.append(
  _PAGE.fields_by_name['owner_user_id'])
_PAGE.fields_by_name['owner_user_id'].containing_oneof = _PAGE.oneofs_by_name['owner']
_PAGE.oneofs_by_name['owner'].fields.append(
  _PAGE.fields_by_name['owner_community_id'])
_PAGE.fields_by_name['owner_community_id'].containing_oneof = _PAGE.oneofs_by_name['owner']
_PAGE.oneofs_by_name['owner'].fields.append(
  _PAGE.fields_by_name['owner_group_id'])
_PAGE.fields_by_name['owner_group_id'].containing_oneof = _PAGE.oneofs_by_name['owner']
_CREATEPLACEREQ.fields_by_name['location'].message_type = _COORDINATE
_CREATEGUIDEREQ.fields_by_name['location'].message_type = _COORDINATE
_UPDATEPAGEREQ.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPAGEREQ.fields_by_name['content'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPAGEREQ.fields_by_name['photo_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPAGEREQ.fields_by_name['address'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEPAGEREQ.fields_by_name['location'].message_type = _COORDINATE
_TRANSFERPAGEREQ.oneofs_by_name['new_owner'].fields.append(
  _TRANSFERPAGEREQ.fields_by_name['new_owner_community_id'])
_TRANSFERPAGEREQ.fields_by_name['new_owner_community_id'].containing_oneof = _TRANSFERPAGEREQ.oneofs_by_name['new_owner']
_TRANSFERPAGEREQ.oneofs_by_name['new_owner'].fields.append(
  _TRANSFERPAGEREQ.fields_by_name['new_owner_group_id'])
_TRANSFERPAGEREQ.fields_by_name['new_owner_group_id'].containing_oneof = _TRANSFERPAGEREQ.oneofs_by_name['new_owner']
_LISTUSERPLACESRES.fields_by_name['places'].message_type = _PAGE
_LISTUSERGUIDESRES.fields_by_name['guides'].message_type = _PAGE
DESCRIPTOR.message_types_by_name['Coordinate'] = _COORDINATE
DESCRIPTOR.message_types_by_name['Page'] = _PAGE
DESCRIPTOR.message_types_by_name['CreatePlaceReq'] = _CREATEPLACEREQ
DESCRIPTOR.message_types_by_name['CreateGuideReq'] = _CREATEGUIDEREQ
DESCRIPTOR.message_types_by_name['GetPageReq'] = _GETPAGEREQ
DESCRIPTOR.message_types_by_name['UpdatePageReq'] = _UPDATEPAGEREQ
DESCRIPTOR.message_types_by_name['TransferPageReq'] = _TRANSFERPAGEREQ
DESCRIPTOR.message_types_by_name['ListUserPlacesReq'] = _LISTUSERPLACESREQ
DESCRIPTOR.message_types_by_name['ListUserPlacesRes'] = _LISTUSERPLACESRES
DESCRIPTOR.message_types_by_name['ListUserGuidesReq'] = _LISTUSERGUIDESREQ
DESCRIPTOR.message_types_by_name['ListUserGuidesRes'] = _LISTUSERGUIDESRES
DESCRIPTOR.enum_types_by_name['PageType'] = _PAGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Coordinate = _reflection.GeneratedProtocolMessageType('Coordinate', (_message.Message,), {
  'DESCRIPTOR' : _COORDINATE,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.Coordinate)
  })
_sym_db.RegisterMessage(Coordinate)

Page = _reflection.GeneratedProtocolMessageType('Page', (_message.Message,), {
  'DESCRIPTOR' : _PAGE,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.Page)
  })
_sym_db.RegisterMessage(Page)

CreatePlaceReq = _reflection.GeneratedProtocolMessageType('CreatePlaceReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEREQ,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.CreatePlaceReq)
  })
_sym_db.RegisterMessage(CreatePlaceReq)

CreateGuideReq = _reflection.GeneratedProtocolMessageType('CreateGuideReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGUIDEREQ,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.CreateGuideReq)
  })
_sym_db.RegisterMessage(CreateGuideReq)

GetPageReq = _reflection.GeneratedProtocolMessageType('GetPageReq', (_message.Message,), {
  'DESCRIPTOR' : _GETPAGEREQ,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.GetPageReq)
  })
_sym_db.RegisterMessage(GetPageReq)

UpdatePageReq = _reflection.GeneratedProtocolMessageType('UpdatePageReq', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPAGEREQ,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.UpdatePageReq)
  })
_sym_db.RegisterMessage(UpdatePageReq)

TransferPageReq = _reflection.GeneratedProtocolMessageType('TransferPageReq', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERPAGEREQ,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.TransferPageReq)
  })
_sym_db.RegisterMessage(TransferPageReq)

ListUserPlacesReq = _reflection.GeneratedProtocolMessageType('ListUserPlacesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERPLACESREQ,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.ListUserPlacesReq)
  })
_sym_db.RegisterMessage(ListUserPlacesReq)

ListUserPlacesRes = _reflection.GeneratedProtocolMessageType('ListUserPlacesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERPLACESRES,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.ListUserPlacesRes)
  })
_sym_db.RegisterMessage(ListUserPlacesRes)

ListUserGuidesReq = _reflection.GeneratedProtocolMessageType('ListUserGuidesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERGUIDESREQ,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.ListUserGuidesReq)
  })
_sym_db.RegisterMessage(ListUserGuidesReq)

ListUserGuidesRes = _reflection.GeneratedProtocolMessageType('ListUserGuidesRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERGUIDESRES,
  '__module__' : 'pages_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.pages.ListUserGuidesRes)
  })
_sym_db.RegisterMessage(ListUserGuidesRes)



_PAGES = _descriptor.ServiceDescriptor(
  name='Pages',
  full_name='org.couchers.api.pages.Pages',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=1891,
  serialized_end=2543,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreatePlace',
    full_name='org.couchers.api.pages.Pages.CreatePlace',
    index=0,
    containing_service=None,
    input_type=_CREATEPLACEREQ,
    output_type=_PAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateGuide',
    full_name='org.couchers.api.pages.Pages.CreateGuide',
    index=1,
    containing_service=None,
    input_type=_CREATEGUIDEREQ,
    output_type=_PAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPage',
    full_name='org.couchers.api.pages.Pages.GetPage',
    index=2,
    containing_service=None,
    input_type=_GETPAGEREQ,
    output_type=_PAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePage',
    full_name='org.couchers.api.pages.Pages.UpdatePage',
    index=3,
    containing_service=None,
    input_type=_UPDATEPAGEREQ,
    output_type=_PAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransferPage',
    full_name='org.couchers.api.pages.Pages.TransferPage',
    index=4,
    containing_service=None,
    input_type=_TRANSFERPAGEREQ,
    output_type=_PAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserPlaces',
    full_name='org.couchers.api.pages.Pages.ListUserPlaces',
    index=5,
    containing_service=None,
    input_type=_LISTUSERPLACESREQ,
    output_type=_LISTUSERPLACESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserGuides',
    full_name='org.couchers.api.pages.Pages.ListUserGuides',
    index=6,
    containing_service=None,
    input_type=_LISTUSERGUIDESREQ,
    output_type=_LISTUSERGUIDESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PAGES)

DESCRIPTOR.services_by_name['Pages'] = _PAGES

# @@protoc_insertion_point(module_scope)
