# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admin.proto',
  package='org.couchers.admin',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0b\x61\x64min.proto\x12\x12org.couchers.admin\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\"\x83\x01\n\x0bUserDetails\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12\x11\n\tbirthdate\x18\x07 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x05 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\"!\n\x11GetUserDetailsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x13\n\x11GetUserDetailsRes\"3\n\x13\x43hangeUserGenderReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06gender\x18\x02 \x01(\t\"9\n\x16\x43hangeUserBirthdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"\x1a\n\nBanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1d\n\rDeleteUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0f\x43reateApiKeyReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x11\n\x0f\x43reateApiKeyRes\"\x81\x01\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t2\x93\x05\n\x05\x41\x64min\x12Z\n\x0eGetUserDetails\x12%.org.couchers.admin.GetUserDetailsReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12^\n\x10\x43hangeUserGender\x12\'.org.couchers.admin.ChangeUserGenderReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x64\n\x13\x43hangeUserBirthdate\x12*.org.couchers.admin.ChangeUserBirthdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12L\n\x07\x42\x61nUser\x12\x1e.org.couchers.admin.BanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nDeleteUser\x12!.org.couchers.admin.DeleteUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12Z\n\x0c\x43reateApiKey\x12#.org.couchers.admin.CreateApiKeyReq\x1a#.org.couchers.admin.CreateApiKeyRes\"\x00\x12\x64\n\x0f\x43reateCommunity\x12&.org.couchers.admin.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3'
  ,
  dependencies=[annotations__pb2.DESCRIPTOR,communities__pb2.DESCRIPTOR,])




_USERDETAILS = _descriptor.Descriptor(
  name='UserDetails',
  full_name='org.couchers.admin.UserDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.admin.UserDetails.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.admin.UserDetails.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.admin.UserDetails.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.admin.UserDetails.gender', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthdate', full_name='org.couchers.admin.UserDetails.birthdate', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='banned', full_name='org.couchers.admin.UserDetails.banned', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='org.couchers.admin.UserDetails.deleted', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=205,
)


_GETUSERDETAILSREQ = _descriptor.Descriptor(
  name='GetUserDetailsReq',
  full_name='org.couchers.admin.GetUserDetailsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.GetUserDetailsReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=207,
  serialized_end=240,
)


_GETUSERDETAILSRES = _descriptor.Descriptor(
  name='GetUserDetailsRes',
  full_name='org.couchers.admin.GetUserDetailsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=261,
)


_CHANGEUSERGENDERREQ = _descriptor.Descriptor(
  name='ChangeUserGenderReq',
  full_name='org.couchers.admin.ChangeUserGenderReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.ChangeUserGenderReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.admin.ChangeUserGenderReq.gender', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=314,
)


_CHANGEUSERBIRTHDATEREQ = _descriptor.Descriptor(
  name='ChangeUserBirthdateReq',
  full_name='org.couchers.admin.ChangeUserBirthdateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.ChangeUserBirthdateReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthdate', full_name='org.couchers.admin.ChangeUserBirthdateReq.birthdate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=373,
)


_BANUSERREQ = _descriptor.Descriptor(
  name='BanUserReq',
  full_name='org.couchers.admin.BanUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.BanUserReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=401,
)


_DELETEUSERREQ = _descriptor.Descriptor(
  name='DeleteUserReq',
  full_name='org.couchers.admin.DeleteUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.DeleteUserReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=432,
)


_CREATEAPIKEYREQ = _descriptor.Descriptor(
  name='CreateApiKeyReq',
  full_name='org.couchers.admin.CreateApiKeyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.admin.CreateApiKeyReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=465,
)


_CREATEAPIKEYRES = _descriptor.Descriptor(
  name='CreateApiKeyRes',
  full_name='org.couchers.admin.CreateApiKeyRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=484,
)


_CREATECOMMUNITYREQ = _descriptor.Descriptor(
  name='CreateCommunityReq',
  full_name='org.couchers.admin.CreateCommunityReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.admin.CreateCommunityReq.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.admin.CreateCommunityReq.slug', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.admin.CreateCommunityReq.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_node_id', full_name='org.couchers.admin.CreateCommunityReq.parent_node_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_ids', full_name='org.couchers.admin.CreateCommunityReq.admin_ids', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geojson', full_name='org.couchers.admin.CreateCommunityReq.geojson', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=616,
)

DESCRIPTOR.message_types_by_name['UserDetails'] = _USERDETAILS
DESCRIPTOR.message_types_by_name['GetUserDetailsReq'] = _GETUSERDETAILSREQ
DESCRIPTOR.message_types_by_name['GetUserDetailsRes'] = _GETUSERDETAILSRES
DESCRIPTOR.message_types_by_name['ChangeUserGenderReq'] = _CHANGEUSERGENDERREQ
DESCRIPTOR.message_types_by_name['ChangeUserBirthdateReq'] = _CHANGEUSERBIRTHDATEREQ
DESCRIPTOR.message_types_by_name['BanUserReq'] = _BANUSERREQ
DESCRIPTOR.message_types_by_name['DeleteUserReq'] = _DELETEUSERREQ
DESCRIPTOR.message_types_by_name['CreateApiKeyReq'] = _CREATEAPIKEYREQ
DESCRIPTOR.message_types_by_name['CreateApiKeyRes'] = _CREATEAPIKEYRES
DESCRIPTOR.message_types_by_name['CreateCommunityReq'] = _CREATECOMMUNITYREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserDetails = _reflection.GeneratedProtocolMessageType('UserDetails', (_message.Message,), {
  'DESCRIPTOR' : _USERDETAILS,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.UserDetails)
  })
_sym_db.RegisterMessage(UserDetails)

GetUserDetailsReq = _reflection.GeneratedProtocolMessageType('GetUserDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERDETAILSREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.GetUserDetailsReq)
  })
_sym_db.RegisterMessage(GetUserDetailsReq)

GetUserDetailsRes = _reflection.GeneratedProtocolMessageType('GetUserDetailsRes', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERDETAILSRES,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.GetUserDetailsRes)
  })
_sym_db.RegisterMessage(GetUserDetailsRes)

ChangeUserGenderReq = _reflection.GeneratedProtocolMessageType('ChangeUserGenderReq', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEUSERGENDERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.ChangeUserGenderReq)
  })
_sym_db.RegisterMessage(ChangeUserGenderReq)

ChangeUserBirthdateReq = _reflection.GeneratedProtocolMessageType('ChangeUserBirthdateReq', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEUSERBIRTHDATEREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.ChangeUserBirthdateReq)
  })
_sym_db.RegisterMessage(ChangeUserBirthdateReq)

BanUserReq = _reflection.GeneratedProtocolMessageType('BanUserReq', (_message.Message,), {
  'DESCRIPTOR' : _BANUSERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.BanUserReq)
  })
_sym_db.RegisterMessage(BanUserReq)

DeleteUserReq = _reflection.GeneratedProtocolMessageType('DeleteUserReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.DeleteUserReq)
  })
_sym_db.RegisterMessage(DeleteUserReq)

CreateApiKeyReq = _reflection.GeneratedProtocolMessageType('CreateApiKeyReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.CreateApiKeyReq)
  })
_sym_db.RegisterMessage(CreateApiKeyReq)

CreateApiKeyRes = _reflection.GeneratedProtocolMessageType('CreateApiKeyRes', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYRES,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.CreateApiKeyRes)
  })
_sym_db.RegisterMessage(CreateApiKeyRes)

CreateCommunityReq = _reflection.GeneratedProtocolMessageType('CreateCommunityReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMUNITYREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.admin.CreateCommunityReq)
  })
_sym_db.RegisterMessage(CreateCommunityReq)



_ADMIN = _descriptor.ServiceDescriptor(
  name='Admin',
  full_name='org.couchers.admin.Admin',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\004',
  create_key=_descriptor._internal_create_key,
  serialized_start=619,
  serialized_end=1278,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetUserDetails',
    full_name='org.couchers.admin.Admin.GetUserDetails',
    index=0,
    containing_service=None,
    input_type=_GETUSERDETAILSREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeUserGender',
    full_name='org.couchers.admin.Admin.ChangeUserGender',
    index=1,
    containing_service=None,
    input_type=_CHANGEUSERGENDERREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeUserBirthdate',
    full_name='org.couchers.admin.Admin.ChangeUserBirthdate',
    index=2,
    containing_service=None,
    input_type=_CHANGEUSERBIRTHDATEREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BanUser',
    full_name='org.couchers.admin.Admin.BanUser',
    index=3,
    containing_service=None,
    input_type=_BANUSERREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUser',
    full_name='org.couchers.admin.Admin.DeleteUser',
    index=4,
    containing_service=None,
    input_type=_DELETEUSERREQ,
    output_type=_USERDETAILS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateApiKey',
    full_name='org.couchers.admin.Admin.CreateApiKey',
    index=5,
    containing_service=None,
    input_type=_CREATEAPIKEYREQ,
    output_type=_CREATEAPIKEYRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCommunity',
    full_name='org.couchers.admin.Admin.CreateCommunity',
    index=6,
    containing_service=None,
    input_type=_CREATECOMMUNITYREQ,
    output_type=communities__pb2._COMMUNITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMIN)

DESCRIPTOR.services_by_name['Admin'] = _ADMIN

# @@protoc_insertion_point(module_scope)
