# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gis.proto',
  package='org.couchers.json',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tgis.proto\x12\x11org.couchers.json\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto2\xe3\x02\n\x03GIS\x12P\n\x08GetUsers\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/geojson/users\x12\\\n\x0eGetCommunities\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/geojson/communities\x12R\n\tGetPlaces\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/places\x12R\n\tGetGuides\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/guides\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_httpbody__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_GIS = _descriptor.ServiceDescriptor(
  name='GIS',
  full_name='org.couchers.json.GIS',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=138,
  serialized_end=493,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetUsers',
    full_name='org.couchers.json.GIS.GetUsers',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\020\022\016/geojson/users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommunities',
    full_name='org.couchers.json.GIS.GetCommunities',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\026\022\024/geojson/communities',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPlaces',
    full_name='org.couchers.json.GIS.GetPlaces',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\021\022\017/geojson/places',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGuides',
    full_name='org.couchers.json.GIS.GetGuides',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\202\323\344\223\002\021\022\017/geojson/guides',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GIS)

DESCRIPTOR.services_by_name['GIS'] = _GIS

# @@protoc_insertion_point(module_scope)
