# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: threads.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='threads.proto',
  package='org.couchers.api.threads',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rthreads.proto\x12\x18org.couchers.api.threads\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"2\n\x06Thread\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x15\n\rnum_responses\x18\x02 \x01(\x03\"H\n\x0cGetThreadReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Y\n\x0cGetThreadRes\x12\x30\n\x07replies\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\x8a\x01\n\x05Reply\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x16\n\x0e\x61uthor_user_id\x18\x03 \x01(\x03\x12\x30\n\x0c\x63reated_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnum_replies\x18\x05 \x01(\r\"2\n\x0cPostReplyReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"!\n\x0cPostReplyRes\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x32\xc9\x01\n\x07Threads\x12[\n\tGetThread\x12&.org.couchers.api.threads.GetThreadReq\x1a&.org.couchers.api.threads.GetThreadRes\x12[\n\tPostReply\x12&.org.couchers.api.threads.PostReplyReq\x1a&.org.couchers.api.threads.PostReplyRes\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,])




_THREAD = _descriptor.Descriptor(
  name='Thread',
  full_name='org.couchers.api.threads.Thread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.Thread.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_responses', full_name='org.couchers.api.threads.Thread.num_responses', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=145,
)


_GETTHREADREQ = _descriptor.Descriptor(
  name='GetThreadReq',
  full_name='org.couchers.api.threads.GetThreadReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.GetThreadReq.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='org.couchers.api.threads.GetThreadReq.page_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='org.couchers.api.threads.GetThreadReq.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=219,
)


_GETTHREADRES = _descriptor.Descriptor(
  name='GetThreadRes',
  full_name='org.couchers.api.threads.GetThreadRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='replies', full_name='org.couchers.api.threads.GetThreadRes.replies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='org.couchers.api.threads.GetThreadRes.next_page_token', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=310,
)


_REPLY = _descriptor.Descriptor(
  name='Reply',
  full_name='org.couchers.api.threads.Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.Reply.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.threads.Reply.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author_user_id', full_name='org.couchers.api.threads.Reply.author_user_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_time', full_name='org.couchers.api.threads.Reply.created_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_replies', full_name='org.couchers.api.threads.Reply.num_replies', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=451,
)


_POSTREPLYREQ = _descriptor.Descriptor(
  name='PostReplyReq',
  full_name='org.couchers.api.threads.PostReplyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.PostReplyReq.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='org.couchers.api.threads.PostReplyReq.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=503,
)


_POSTREPLYRES = _descriptor.Descriptor(
  name='PostReplyRes',
  full_name='org.couchers.api.threads.PostReplyRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_id', full_name='org.couchers.api.threads.PostReplyRes.thread_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=538,
)

_GETTHREADRES.fields_by_name['replies'].message_type = _REPLY
_REPLY.fields_by_name['created_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Thread'] = _THREAD
DESCRIPTOR.message_types_by_name['GetThreadReq'] = _GETTHREADREQ
DESCRIPTOR.message_types_by_name['GetThreadRes'] = _GETTHREADRES
DESCRIPTOR.message_types_by_name['Reply'] = _REPLY
DESCRIPTOR.message_types_by_name['PostReplyReq'] = _POSTREPLYREQ
DESCRIPTOR.message_types_by_name['PostReplyRes'] = _POSTREPLYRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Thread = _reflection.GeneratedProtocolMessageType('Thread', (_message.Message,), {
  'DESCRIPTOR' : _THREAD,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.Thread)
  })
_sym_db.RegisterMessage(Thread)

GetThreadReq = _reflection.GeneratedProtocolMessageType('GetThreadReq', (_message.Message,), {
  'DESCRIPTOR' : _GETTHREADREQ,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.GetThreadReq)
  })
_sym_db.RegisterMessage(GetThreadReq)

GetThreadRes = _reflection.GeneratedProtocolMessageType('GetThreadRes', (_message.Message,), {
  'DESCRIPTOR' : _GETTHREADRES,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.GetThreadRes)
  })
_sym_db.RegisterMessage(GetThreadRes)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.Reply)
  })
_sym_db.RegisterMessage(Reply)

PostReplyReq = _reflection.GeneratedProtocolMessageType('PostReplyReq', (_message.Message,), {
  'DESCRIPTOR' : _POSTREPLYREQ,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.PostReplyReq)
  })
_sym_db.RegisterMessage(PostReplyReq)

PostReplyRes = _reflection.GeneratedProtocolMessageType('PostReplyRes', (_message.Message,), {
  'DESCRIPTOR' : _POSTREPLYRES,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.threads.PostReplyRes)
  })
_sym_db.RegisterMessage(PostReplyRes)



_THREADS = _descriptor.ServiceDescriptor(
  name='Threads',
  full_name='org.couchers.api.threads.Threads',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=541,
  serialized_end=742,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetThread',
    full_name='org.couchers.api.threads.Threads.GetThread',
    index=0,
    containing_service=None,
    input_type=_GETTHREADREQ,
    output_type=_GETTHREADRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostReply',
    full_name='org.couchers.api.threads.Threads.PostReply',
    index=1,
    containing_service=None,
    input_type=_POSTREPLYREQ,
    output_type=_POSTREPLYRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_THREADS)

DESCRIPTOR.services_by_name['Threads'] = _THREADS

# @@protoc_insertion_point(module_scope)
